@@ -1,7 +1,7 @@
 package Moose::Autobox::Indexed;     
 use Moose::Role 'requires';
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 requires 'at';
 requires 'put';
@@ -10,6 +10,7 @@ requires 'keys';
 requires 'values'; 
 requires 'kv';
 requires 'slice';
+requires qw(each each_key each_value);
 
 1;
 
@@ -54,6 +55,14 @@ and L<Moose::Autobox::Hash> implement this role.
 
 =item B<kv>
 
+=item B<slice>
+
+=item B<each>
+
+=item B<each_key>
+
+=item B<each_value>
+
 =back
 
 =head1 BUGS
