@@ -1,7 +1,7 @@
 package Moose::Autobox::String;
 use Moose::Role;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 with 'Moose::Autobox::Value';
 
@@ -15,6 +15,8 @@ sub chomp   { CORE::chomp   $_[0] }
 sub chop    { CORE::chop    $_[0] }
 sub reverse { CORE::reverse $_[0] }
 sub length  { CORE::length  $_[0] }
+sub lines   { [ CORE::split '\n', $_[0] ] }
+sub words   { [ CORE::split ' ',  $_[0] ] }
 sub index   { 
     return CORE::index($_[0], $_[1]) if scalar @_ == 2;
     return CORE::index($_[0], $_[1], $_[2]);
@@ -23,6 +25,10 @@ sub rindex  {
     return CORE::rindex($_[0], $_[1]) if scalar @_ == 2;
     return CORE::rindex($_[0], $_[1], $_[2]);
 }
+sub split   {
+    return [ CORE::split($_[1], $_[0]) ] if scalar @_ == 2;
+    return [ CORE::split($_[1], $_[0], $_[2]) ];
+}
 
 1;
 
@@ -68,6 +74,18 @@ This is a role to describes a String value.
 
 =item B<ucfirst>
 
+=item B<split>
+
+  $string->split($pattern);
+
+=item B<words>
+
+This is equivalent to splitting on space.
+
+=item B<lines>
+
+This is equivalent to splitting on linelines.
+
 =back
 
 =over 4
